@@ -103,11 +103,11 @@ OC.L10N.register(
     "Enter a valid password" : "Kirjoita oikea salasana",
     "Generate a new password" : "Luo uusi salasana",
     "Your administrator has enforced a password protection." : "Ylläpitäjä on pakottanut salasanasuojauksen.",
-    "Link copied to clipboard" : "Linkki kopioitu leikepöydälle",
+    "Link copied" : "Linkki kopioitu",
     "Email already added" : "Sähköpostiosoite on jo lisätty",
     "Invalid email address" : "Virheellinen sähköpostiosoite",
     "Share link" : "Jaa linkki",
-    "Copy to clipboard" : "Kopioi leikepöydälle",
+    "Copy" : "Kopioi",
     "Send link via email" : "Lähetä linkki sähköpostitse",
     "Select a destination" : "Valitse sijainti",
     "Select" : "Valitse",
@@ -130,7 +130,6 @@ OC.L10N.register(
     "Set default folder for accepted shares" : "Aseta oletuskansio hyväksytyille jaoille",
     "Reset" : "Palauta",
     "Reset folder to system default" : "Palauta kansio järjestelmän oletukseksi",
-    "Share expiration: " : "Jaon vanhentuminen:",
     "group" : "ryhmä",
     "conversation" : "keskustelu",
     "remote" : "etä",
@@ -144,8 +143,7 @@ OC.L10N.register(
     "Via “{folder}”" : "“{folder}” kautta",
     "Unshare" : "Lopeta jakaminen",
     "Cannot copy, please copy the link manually" : "Kopioiminen ei onnistu. Kopioi linkki manuaalisesti",
-    "Copy internal link to clipboard" : "Kopioi sisäinen linkki leikepöydälle",
-    "Link copied" : "Linkki kopioitu",
+    "Copy internal link" : "Kopioi sisäinen linkki",
     "Internal link" : "Sisäinen linkki",
     "Shared via link by {initiator}" : "Jaettu linkin kautta käyttäjältä {initiator}",
     "Mail share ({label})" : "Sähköpostijako ({label})",
@@ -153,7 +151,6 @@ OC.L10N.register(
     "Share link ({index})" : "Jaa linkki ({index})",
     "Create public link" : "Luo julkinen linkki",
     "Actions for \"{title}\"" : "Toiminnot kohteelle \"{title}\"",
-    "Copy public link of \"{title}\" to clipboard" : "Kopioi kohteen \"{title}\" julkinen linkki leikepöydälle",
     "Error, please enter proper password and/or expiration date" : "Virhe, lisää kelvollinen salasana ja/tai päättymispäivä",
     "Link share created" : "Linkkijako luotu",
     "Error while creating the share" : "Virhe jakoa luotaessa",
@@ -174,7 +171,7 @@ OC.L10N.register(
     "Name, email, or Federated Cloud ID …" : "Nimi, sähköposti tai federoitu Cloud ID...",
     "Searching …" : "Haetaan…",
     "No elements found." : "Elementtejä ei löytynyt.",
-    "Search globally" : "Hae globaalisti",
+    "Search everywhere" : "Etsi kaikkialta",
     "Guest" : "Vieras",
     "Group" : "Ryhmä",
     "Email" : "Sähköposti",
@@ -188,7 +185,6 @@ OC.L10N.register(
     "By uploading files, you agree to the terms of service." : "Lähettämällä tiedostot hyväksyt käyttöehdot.",
     "View terms of service" : "Näytä käyttöehdot",
     "Terms of service" : "Käyttöehdot",
-    "Share with {userName}" : "Jaa käyttäjän {userName} kanssa",
     "Share with group" : "Jaa ryhmän kanssa",
     "Share in conversation" : "Jaa keskustelussa",
     "Share with remote group" : "Jaa etäryhmän kanssa",
@@ -235,7 +231,7 @@ OC.L10N.register(
     "Shared" : "Jaettu",
     "Shared by {ownerDisplayName}" : "Jakanut {ownerDisplayName}",
     "Shared multiple times with different people" : "Jaettu useita kertoja eri ihmisten kanssa",
-    "Show sharing options" : "Näytä jakamisen valinnat",
+    "Sharing options" : "Jakamisen valinnat",
     "Shared with others" : "Jaettu muiden kanssa",
     "Upload files to {foldername}" : "Lähetä tiedostot kansioon {foldername}",
     "Public file share" : "Julkinen tiedostojako",
@@ -277,16 +273,6 @@ OC.L10N.register(
     "Shared with you and {circle} by {owner}" : "{owner} on jakanut tämän sinun ja piirin {circle} kanssa",
     "Shared with you and the conversation {conversation} by {owner}" : "{owner} on jakanut tämän sinun ja keskustelun {conversation} kanssa",
     "Shared with you in a conversation by {owner}" : "{owner} jakoi tämän kanssasi keskustelussa",
-    "Share note" : "Jaa muistiinpano",
-    "Show list view" : "Näytä listanäkymä",
-    "Show grid view" : "Näytä ruudukkonäkymä",
-    "Upload files to %s" : "Lähetä tiedostoja käyttäjälle %s",
-    "%s shared a folder with you." : "%s jakoi kansion kanssasi.",
-    "Note" : "Huomio",
-    "Select or drop files" : "Valitse tai pudota tiedostoja",
-    "Uploading files" : "Lähetetään tiedostoja",
-    "Uploaded files:" : "Lähetetyt tiedostot:",
-    "By uploading files, you agree to the %1$sterms of service%2$s." : "Tiedostoja lähettämällä hyväksyt %1$skäyttöehdot%2$s.",
     "Share not found" : "Jakoa ei löytynyt",
     "Back to %s" : "Takaisin kohtaan %s",
     "Add to your Nextcloud" : "Lisää Nextcloudiisi",
@@ -296,13 +282,30 @@ OC.L10N.register(
     "This will stop your current uploads." : "Tämä pysäyttää meneillään olevat lähetykset.",
     "Move or copy" : "Siirrä tai kopioi",
     "You can upload into this folder" : "Voit lähettää tiedostoja tähän kansioon",
+    "Show list view" : "Näytä listanäkymä",
+    "Show grid view" : "Näytä ruudukkonäkymä",
     "No compatible server found at {remote}" : "Yhteensopivaa palvelinta ei löytynyt osoitteesta {remote}",
     "Invalid server URL" : "Virheellinen palvelimen URL",
     "Failed to add the public link to your Nextcloud" : "Julkisen linkin lisääminen Nextcloudiisi epäonnistui",
     "Download all files" : "Lataa kaikki tiedostot",
+    "Link copied to clipboard" : "Linkki kopioitu leikepöydälle",
+    "Copy to clipboard" : "Kopioi leikepöydälle",
+    "Copy internal link to clipboard" : "Kopioi sisäinen linkki leikepöydälle",
+    "Copy public link of \"{title}\" to clipboard" : "Kopioi kohteen \"{title}\" julkinen linkki leikepöydälle",
+    "Search globally" : "Hae globaalisti",
     "Search for share recipients" : "Etsi jaon vastaanottajia",
     "No recommendations. Start typing." : "Ei suosituksia. Aloita kirjoittaminen.",
     "Enter your name" : "Kirjoita nimesi",
+    "Share with {userName}" : "Jaa käyttäjän {userName} kanssa",
+    "Show sharing options" : "Näytä jakamisen valinnat",
+    "Share note" : "Jaa muistiinpano",
+    "Upload files to %s" : "Lähetä tiedostoja käyttäjälle %s",
+    "%s shared a folder with you." : "%s jakoi kansion kanssasi.",
+    "Note" : "Huomio",
+    "Select or drop files" : "Valitse tai pudota tiedostoja",
+    "Uploading files" : "Lähetetään tiedostoja",
+    "Uploaded files:" : "Lähetetyt tiedostot:",
+    "By uploading files, you agree to the %1$sterms of service%2$s." : "Tiedostoja lähettämällä hyväksyt %1$skäyttöehdot%2$s.",
     "Name" : "Nimi",
     "Filename must not be empty." : "Tiedostonimi ei voi olla tyhjä."
 },
