@@ -106,7 +106,6 @@ OC.L10N.register(
     "About" : "Despre",
     "Display name" : "Nume afișat",
     "Headline" : "Titlu",
-    "Organisation" : "Organizație",
     "Role" : "Rol",
     "Additional settings" : "Setări adiționale",
     "Enter the database name for %s" : "Introduceți numele bazei de date pentru %s",
@@ -190,8 +189,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Nu se poate scrie în directorul \"config\".",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Aceasta se poate remedia de obicei prin asigurarea accesului în scriere serverului la directorul configurației. Vedeți  %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Sau, dacă preferați să păstrați config.php doar în citire, setați opțiunea \"config_is_read_only\" ca true. Vedeți %s",
-    "Cannot write into \"apps\" directory." : "Nu se poate scrie în directorul \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Aceasta se poate remedia permițând serverului web să acceseze directorul aplicațiilor sau dezactivând App Store în fișierul de configurație.",
     "Cannot create \"data\" directory." : "Nu se poate crea directorul \"data\".",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Aceasta se remediază de obicei permițând serverului web accesul în scriere în directorul rădăcină. Vedeți %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Permisiunile se rezolvă de obicei dând serverului web acces în scriere în directorul rădăcină. Vedeți  %s.",
@@ -224,6 +221,8 @@ OC.L10N.register(
     "Storage connection error. %s" : "Eroare conexiune cu spațiul de stocare. %s",
     "Storage is temporarily not available" : "Spațiu de stocare este indisponibil temporar",
     "Storage connection timeout. %s" : "Timeout la conexiunea cu spațiul de stocare. %s",
+    "Images" : "Imagini",
+    "Question" : "Întrebare",
     "Generates a possible headline for a text." : "Generează un posibil titlu pentru text",
     "Text" : "Text",
     "Summarize" : "Rezumă",
@@ -235,7 +234,10 @@ OC.L10N.register(
     "Generate headline" : "Generează titlu",
     "Summarizes text by reducing its length without losing key information." : "Rezumă textul prin reducerea lungimii acestuia, fără a pierde informațiile cheie.",
     "Extracts topics from a text and outputs them separated by commas." : "Extrage subiecte din text și le furnizează separate prin virgulă.",
+    "Organisation" : "Organizație",
     "File is currently busy, please try again later" : "Fișierul este blocat momentan, încercați din nou mai târziu",
-    "Cannot download file" : "Fișierul nu se poate descărca"
+    "Cannot download file" : "Fișierul nu se poate descărca",
+    "Cannot write into \"apps\" directory." : "Nu se poate scrie în directorul \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Aceasta se poate remedia permițând serverului web să acceseze directorul aplicațiilor sau dezactivând App Store în fișierul de configurație."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
